@@ -15,7 +15,7 @@ use English qw/ -no_match_vars /;
 use base qw/Exporter/;
 use Path::Class qw/file/;
 
-our $VERSION     = version->new('0.3.0');
+our $VERSION     = version->new('0.4.0');
 our @EXPORT_OK   = qw//;
 our %EXPORT_TAGS = ();
 
@@ -194,7 +194,7 @@ sub log {
 
     my $system = $self->which($dir);
 
-    return $system->log($dir, @args);
+    return $system->log($file, @args);
 }
 
 sub cat {
@@ -292,7 +292,7 @@ VCS::Which - Generically interface with version control systems
 
 =head1 VERSION
 
-This documentation refers to VCS::Which version 0.3.0.
+This documentation refers to VCS::Which version 0.4.0.
 
 
 =head1 SYNOPSIS
