@@ -17,7 +17,7 @@ use Path::Class;
 use File::chdir;
 use Contextual::Return;
 
-our $VERSION = version->new('0.3.0');
+our $VERSION = version->new('0.4.0');
 our $name    = 'Subversion';
 our $exe     = 'svn';
 our $meta    = '.svn';
@@ -135,7 +135,7 @@ sub log {
 }
 
 sub versions {
-    my ($self, $file, $before_version, $max) = @_;
+    my ($self, $file, $oldest, $newest, $max) = @_;
 
     $file = file($file);
     local $CWD = -d $file ? $file : $file->parent;
@@ -143,7 +143,7 @@ sub versions {
     my @versions;
 
     for my $log (sort {$a <=> $b} keys %logs) {
-        push @versions, $logs{$log}{rev};# if $before_version && $logs{$log}{rev} <= $before_version;
+        push @versions, $logs{$log}{rev};# if $oldest && $logs{$log}{rev} <= $oldest;
     }
 
     return @versions;
@@ -159,7 +159,7 @@ VCS::Which::Plugin::Subversion - The Subversion plugin for VCS::Which
 
 =head1 VERSION
 
-This documentation refers to VCS::Which::Plugin::Subversion version 0.3.0.
+This documentation refers to VCS::Which::Plugin::Subversion version 0.4.0.
 
 =head1 SYNOPSIS
 
